@@ -170,9 +170,7 @@ class CloudFrontToApiGateway(
 
     @builtins.property # type: ignore
     @jsii.member(jsii_name="cloudFrontWebDistribution")
-    def cloud_front_web_distribution(
-        self,
-    ) -> aws_cdk.aws_cloudfront.CloudFrontWebDistribution:
+    def cloud_front_web_distribution(self) -> aws_cdk.aws_cloudfront.Distribution:
         return jsii.get(self, "cloudFrontWebDistribution")
 
     @builtins.property # type: ignore
